// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KGAPI_VERSION_H
#define KGAPI_VERSION_H

#define KGAPI_VERSION_STRING "5.19.2"
#define KGAPI_VERSION_MAJOR 5
#define KGAPI_VERSION_MINOR 19
#define KGAPI_VERSION_PATCH 2
#define KGAPI_VERSION ((5<<16)|(19<<8)|(2))

#endif
