
#ifndef KGAPICALENDAR_EXPORT_H
#define KGAPICALENDAR_EXPORT_H

#ifdef KGAPICALENDAR_STATIC_DEFINE
#  define KGAPICALENDAR_EXPORT
#  define KGAPICALENDAR_NO_EXPORT
#else
#  ifndef KGAPICALENDAR_EXPORT
#    ifdef KPimGAPICalendar_EXPORTS
        /* We are building this library */
#      define KGAPICALENDAR_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KGAPICALENDAR_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KGAPICALENDAR_NO_EXPORT
#    define KGAPICALENDAR_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KGAPICALENDAR_DEPRECATED
#  define KGAPICALENDAR_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KGAPICALENDAR_DEPRECATED_EXPORT
#  define KGAPICALENDAR_DEPRECATED_EXPORT KGAPICALENDAR_EXPORT KGAPICALENDAR_DEPRECATED
#endif

#ifndef KGAPICALENDAR_DEPRECATED_NO_EXPORT
#  define KGAPICALENDAR_DEPRECATED_NO_EXPORT KGAPICALENDAR_NO_EXPORT KGAPICALENDAR_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KGAPICALENDAR_NO_DEPRECATED
#    define KGAPICALENDAR_NO_DEPRECATED
#  endif
#endif

#endif /* KGAPICALENDAR_EXPORT_H */
